@@ -38,11 +38,11 @@ class UpdateELKAPI:
         result_start_point = self.ELK.get_start_time(self.INDEX_NAME['result'], date_col='pk_id')
 
         if info_start_point is None:
-            info_data = self.orm.query_filter(self.dict_arg["orm_predict_info"], self.n_rows)
-            result_data = self.orm.query_filter(self.dict_arg["orm_predict_result"], self.n_rows)
+            info_data = self.orm.elk_elk_query_filter(self.dict_arg["orm_predict_info"], self.n_rows)
+            result_data = self.orm.elk_query_filter(self.dict_arg["orm_predict_result"], self.n_rows)
         else:
-            info_data = self.orm.query_filter(self.dict_arg["orm_predict_info"], self.n_rows, (self.dict_arg["orm_predict_info"].pk_id > info_start_point))
-            result_data = self.orm.query_filter(self.dict_arg["orm_predict_result"], self.n_rows, (self.dict_arg["orm_predict_result"].pk_id > result_start_point))
+            info_data = self.orm.elk_query_filter(self.dict_arg["orm_predict_info"], self.n_rows, (self.dict_arg["orm_predict_info"].pk_id > info_start_point))
+            result_data = self.orm.elk_query_filter(self.dict_arg["orm_predict_result"], self.n_rows, (self.dict_arg["orm_predict_result"].pk_id > result_start_point))
 
         if info_data.shape[0] == 0 and result_data.shape[0] == 0:
             print(self.dict_arg["modual_name"] + ' Upload Complete ! ')
@@ -56,7 +56,7 @@ class UpdateELKAPI:
                 'info': info_data
             }
         else:
-            predict_data = self.orm.query_filter(self.dict_arg["orm_predict_result"], self.n_rows, (self.dict_arg["orm_result_id"].in_(info_data['pk_id'].tolist())))
+            predict_data = self.orm.elk_query_filter(self.dict_arg["orm_predict_result"], self.n_rows, (self.dict_arg["orm_result_id"].in_(info_data['pk_id'].tolist())))
             info_data, predict_data, merge_data = self.preprocess(info_data, predict_data)
             return {
                 'info': info_data,
